@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-from registry import services
+from .registry import services
 
 
 def query(isbn, service='default'):
